package com.java1234.controller.admin;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.java1234.entity.*;
import com.java1234.service.IOrderDetailService;
import com.java1234.service.IOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 管理端-订单Controller控制器
 * @author java1234_小锋
 * @site www.java1234.com
 * @company 南通小锋网络科技有限公司
 * @create 2022-02-17 7:27
 */
@RestController
@RequestMapping("/admin/order")
public class AdminOrderController {

    @Autowired
    private IOrderService orderService;

    @Autowired
    private IOrderDetailService orderDetailService;

    /**
     * 根据条件分页查询
     * @param pageBean
     * @return
     */
    @RequestMapping("/list")
    public R list(@RequestBody PageBean pageBean){
        System.out.println(pageBean);
        Map<String,Object> map=new HashMap<>();
        map.put("transac_status",pageBean.getQuery().trim());
        map.put("start",pageBean.getStart());
        map.put("pageSize",pageBean.getPageSize());
        List<Order> list = orderService.list(map);
        Long total = orderService.getTotal(map);
        Map<String,Object> resultMap=new HashMap<>();
        resultMap.put("orderList",list);
        resultMap.put("total",total);
        return R.ok(resultMap);
    }

    /**
     * 更新接单状态
     * @param order
     * @return
     */
    @PostMapping("/receiving")
    public R receiving(@RequestBody Order order){
        Order resultOrder = orderService.getById(order.getId());
        resultOrder.setOrder_receiving(order.getOrder_receiving());
        orderService.updateById(resultOrder);
        return R.ok();
    }

    /**
     * 更新结账状态
     * @param order
     * @return
     */
    @PostMapping("/checkout")
    public R checkout(@RequestBody Order order){
        Order resultOrder = orderService.getById(order.getId());
        resultOrder.setTransac_status(order.getTransac_status());
        orderService.updateById(resultOrder);
        return R.ok();
    }

    /**
     * 删除
     * @param id
     * @return
     */
    @GetMapping("/delete/{id}")
    public R delete(@PathVariable(value = "id") Integer id){
        // 删除订单细表的数据
        orderDetailService.remove(new QueryWrapper<OrderDetail>().eq("mId",id));
        orderService.removeById(id);
        return R.ok();
    }

    /**
     *数据分析：七天销售额
     * @return
     */
    @GetMapping("/salesvolume")
    public R salesvolume(){
       List<SalesVolume> salesVolumeList = orderService.getSalesVolume();
        Map<String,Object> resultMap=new HashMap<>();
        resultMap.put("salesVolumeList",salesVolumeList);
        return R.ok(resultMap);
    }

}
